@@ -629,7 +629,6 @@ SCIP_RETCODE primalAddSol(
    )
 {
    SCIP_SOL* sol;
-   /* cppcheck-suppress unassignedVariable */
    SCIP_EVENT event;
    SCIP_Real obj;
    int pos;
@@ -742,7 +741,7 @@ SCIP_RETCODE primalAddSol(
    }
    else
    {
-      if( primal->nsols == set->limit_maxsol )
+      if( primal->nsols == set->limit_maxsol )  /* cppcheck-suppress knownConditionTrueFalse */
       {
          SCIP_CALL( SCIPsolFree(&primal->sols[set->limit_maxsol - 1], blkmem, primal) );
       }
